package Bundle::Tk;

$VERSION = '1.00'

1;

__END__

=head1 NAME

Bundle::Tk - CPAN Bundle for Tk and its dependencies

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Tk'>

=head1 CONTENTS

ExtUtils::MakeMaker  -  should be in perl disribution

Net::NNTP            -  for proto news reader, also pulls in rest of Net::* which LWP needs

Mail::Internet       -  for news again

LWP                  -  for tkweb

Tk                   -  Tk itself!

=head1 DESCRIPTION

=head1 AUTHOR

Nick Ing-Simmons

